@@ -14,7 +14,7 @@ from typing import Callable, Dict, Any
 import json
 import yaml
 
-class StringEnumArg(Enum):
+class StringEnum(Enum):
     def __str__(self):
         return str(self.value)
 
